@@ -17,9 +17,6 @@ public:
     //! Destructor
     virtual ~AboutDlg();
 
-protected:
-    virtual void changeEvent(QEvent *e);
-
 private:
     Ui::AboutDlg *m_ui;
 
