@@ -24,9 +24,19 @@ QtIrreco::QtIrreco(QWidget *parent)
     connect(this,SIGNAL(remoteDeleted()),lw,SLOT(clearScreen()));
 
     useModeEnabled = true;
+    
+    QUrl url;
+    url.setHost("mercury.wipsl.com");
+    url.setPath("/qtirreco/webdb/");
+    url.setPort(80);
 
-   this->checkForRemotes();
-   if(remoteNames->count() != 0) {
+    client = new QxtXmlRpcClient(this, url);
+    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
+    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
+    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
+
+    this->checkForRemotes();
+    if(remoteNames->count() != 0) {
        this->setWindowTitle("QtIrreco:"+activeRemote);
        this->setActiveRemote();
     }
@@ -253,7 +263,7 @@ void QtIrreco::downloadRemote()
 {
     DownloadRemoteDlg *dloadRmDlg = new DownloadRemoteDlg(this,true,remoteNames);
     connect(dloadRmDlg,SIGNAL(lwClearScreen()),lw,SLOT(clearScreen()));
-    connect(dloadRmDlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString, QString, QString, QStringList,int)),this,SLOT(AddButtonToLayout(QString,QString, QString, QString, QStringList,int)));
+    connect(dloadRmDlg,SIGNAL(addButtonToLayoutSignalFromRSD(QString,QString, QString, QString, QStringList,int)),this,SLOT(addButtonToLayout(QString,QString, QString, QString, QStringList,int)));
     connect(dloadRmDlg,SIGNAL(remoteNameToLayoutWidget(QString)),lw,SLOT(setActiveRemoteName(QString)));
     connect(dloadRmDlg,SIGNAL(remoteNameToLayoutWidget(QString)),this,SLOT(addRemoteName(QString)));
     dloadRmDlg->exec();
@@ -291,12 +301,13 @@ void QtIrreco::addRemoteName(QString newRemoteName)
     this->saveRemote();
 }
 
-void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number)
+void QtIrreco::addButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number)
 {
     lw->addButton(fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, number);
 }
-void QtIrreco::AddButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number,int timeOut)
+void QtIrreco::addButtonToLayout(QString fileNameUnPressed, QString fileNamePressed, QString confFileName, QString buttonText, QStringList commands, int number,int timeOut)
 {
+    Q_UNUSED(number);
     lw->addButton(fileNameUnPressed, fileNamePressed, confFileName, buttonText, commands, QPoint(0,0), timeOut);
 }
 
@@ -382,7 +393,7 @@ void QtIrreco::theme()
 void QtIrreco::newButton()
 {
     NewButtonDlg *newButton = new NewButtonDlg(this, lw->vector);
-    connect(newButton,SIGNAL(addButtonToLayoutSignal(QString,QString, QString, QString, QStringList,int,int)),this,SLOT(AddButtonToLayout(QString,QString, QString, QString, QStringList,int,int)));
+    connect(newButton,SIGNAL(addButtonToLayoutSignal(QString,QString, QString, QString, QStringList,int,int)),this,SLOT(addButtonToLayout(QString,QString, QString, QString, QStringList,int,int)));
     newButton->exec();
     delete newButton;
 }
@@ -465,6 +476,7 @@ void QtIrreco::downloadDB()
     DownloadUserRemoteDlg *downloadDlg = new DownloadUserRemoteDlg(this);
     connect(downloadDlg,SIGNAL(remoteDownloaded(QString)),this,SLOT(addDownloadedRemote(QString)));
     downloadDlg->exec();
+    delete downloadDlg;
 }
 
 void QtIrreco::uploadDB()
@@ -840,16 +852,6 @@ void QtIrreco::checkThemesForRemote(QString remoteFile)
         }
     }
 
-    QUrl url;
-    url.setHost("mercury.wipsl.com");
-    url.setPath("/qtirreco/webdb/");
-    url.setPort(80);
-
-    client = new QxtXmlRpcClient(this, url);
-    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
-    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
-
     if(themesForRemote.isEmpty()) {
         lw->setActiveRemoteName(activeRemote);
         this->writeRemoteChanges();
@@ -955,16 +957,6 @@ void QtIrreco::checkLircFilesForRemote(QString remoteFile)
         }
     }
 
-    QUrl url;
-    url.setHost("mercury.wipsl.com");
-    url.setPath("/qtirreco/webdb/");
-    url.setPort(80);
-
-    client = new QxtXmlRpcClient(this, url);
-    connect(client,SIGNAL(finish(int,QVariant)),this,SLOT(processReturnValue(int,QVariant)));
-    connect(client,SIGNAL(networkError(int,QString)),this,SLOT(error(int,QString)));
-    connect(client,SIGNAL(fault(int,int,QString)),this,SLOT(fault(int,int,QString)));
-
     QList<QVariant> params;
     for(callCounter=0;callCounter<lircConfs.length();callCounter++) {
         QMessageBox::information(this,"Lirc configuration","Configuration " + lircConfs.at(callCounter) + " downloaded succesfully!",
@@ -986,7 +978,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         themeDatas = client->call("getThemeById",params);
 
     }
-    if (Id == themeDatas) {
+    else if (Id == themeDatas) {
         QMap<QString,QVariant> array = data.toMap();
         QVariant name = array.value("name");
         themeNameFromConf = name.toString();
@@ -1008,12 +1000,12 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         params.append(downloadId);
         themeButtonIds = client->call("getButtons",params);
     }
-    if (Id == themeButtonIds) {
+    else if (Id == themeButtonIds) {
         dbButtonIdsList = sList;
         this->getThemeButtonsByIds();
 
     }
-    if (Id == buttonData) { // COPY BUTTONS AND MAKE FOLDERS
+    else if (Id == buttonData) { // COPY BUTTONS AND MAKE FOLDERS
 
         progressValue += 100 / (dbButtonIdsList.count()+2);
         emit progressState(progressValue);
@@ -1072,7 +1064,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         // Get button imagedatas and make .png files
         this->getUnpressedImage();
     }
-    if (Id == unpressedToFile)  { // Name always unpressed.png
+    else if (Id == unpressedToFile)  { // Name always unpressed.png
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1080,7 +1072,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/unpressed.png","PNG");
         this->getPressedImage();
     }
-    if (Id == pressedToFile) { // Name always pressed.png
+    else if (Id == pressedToFile) { // Name always pressed.png
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1088,7 +1080,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/pressed.png","PNG");
         this->getThemeButtonsByIds();
     }
-    if (Id == themeBgIds) {
+    else if (Id == themeBgIds) {
         dbBackgroundIdsList = sList;
         if(dbBackgroundIdsList.count() > 0 && !dbBackgroundIdsList.contains("0")) {
             this->setWindowTitle("Downloading theme backgrounds...");
@@ -1099,7 +1091,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
             this->downloadTheme();
         }
     }
-    if (Id == bgData) {
+    else if (Id == bgData) {
         themeBgIndex++;
         progressValue += 100 / (dbButtonIdsList.count()+2);
         emit progressState(progressValue);
@@ -1124,7 +1116,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         // Get background imagedatas and make .png files
         this->getBgImage();
     }
-    if (Id == bgToFile) {
+    else if (Id == bgToFile) {
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
         QByteArray ba = QByteArray::fromBase64(pb);
@@ -1132,7 +1124,7 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
         previewPix.save(bgPath+"/image.png","PNG");
         this->getThemeBackgroundsByIds();
     }
-    if (Id == fileId) {
+    else if (Id == fileId) {
         if(!QFile::exists(devicesPath + lircConfs.at(callCounter-1))) {
             QFile deviceFile(devicesPath +lircConfs.at(callCounter-1));
             deviceFile.open(QIODevice::WriteOnly | QIODevice::Text);
@@ -1180,13 +1172,14 @@ void QtIrreco::processReturnValue(int Id,QVariant data)
 
 void QtIrreco::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error",string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10),string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 
 void QtIrreco::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Fault",string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10), string,
                                  QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void QtIrreco::getUnpressedImage()
