@@ -21,6 +21,7 @@ public:
     void setLabelGeometry(int x,int y,int width,int height);
     void setPushButtonGeometry(int x,int y,int width,int height);
     void hideLineEdit();
+    void enableButton(bool enabled);
 
 protected:
     virtual void changeEvent(QEvent *e);
@@ -30,6 +31,8 @@ private:
 
 private slots:
     void on_changeNameButton_clicked();
+    //! Enable and disable button.
+    void allowButton();
 signals:
     //! Signal to change current remotes name in files.
     void changeName(QString newRemoteName);
