@@ -3,8 +3,6 @@
 #ifndef SOCKET_H
 #define SOCKET_H
 
-
-
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -33,23 +31,15 @@ class Socket : public QObject {
       explicit Socket(QWidget *parent);
       virtual ~Socket();
 
-      //! Server initialization
-      bool create();
-      bool bind ( const int port );
-      bool listen() const;
-      bool accept ( Socket& ) const;
-
       //! Client initialization
+      bool create();
       bool connect ( const std::string host, const int port );
+      int disconnectSocket();
 
       //! Data Transmission
-      bool send ( const std::string ) const;
       void sendSocket(const QString *action);
       int recv ( std::string& ) const;
 
-
-      void set_non_blocking ( const bool );
-
       bool is_valid() const { return m_sock != -1; }
 
  private:
@@ -57,8 +47,6 @@ class Socket : public QObject {
       int m_sock;
       sockaddr_in m_addr;
 
-
 };
 
-
 #endif // SOCKET_H
