@@ -193,7 +193,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         themeNames = client->call("getThemeNameById",params);
 
     }
-    if (Id == themeNames)
+    else if (Id == themeNames)
     {
         dbThemeNamesList.append(sList);
         if(themeNameIndex == 0)
@@ -204,7 +204,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         this->getThemeNamesByIds();
         themeNameIndex++;
     }
-    if (Id == themeDatas)
+    else if (Id == themeDatas)
     {
         m_ui->versionComboBox->clear();
         QMap<QString,QVariant> array = data.toMap();
@@ -235,7 +235,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         themeVersionIds = client->call("getThemeVersionsByName",nameParam);
 
     }
-    if (Id == themeVersionIds)
+    else if (Id == themeVersionIds)
     {
         themeVersionIndex = 0;
         dbThemeVersionIdList = sList;
@@ -248,7 +248,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         themeDates = client->call("getThemeDateById",params);
 
     }
-    if (Id == themeDates)
+    else if (Id == themeDates)
     {
         dbThemeDateList.append(sList);
         if(themeVersionIndex == 0)
@@ -259,7 +259,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         this->getThemeVersionIds();
         themeVersionIndex++;
     }
-    if (Id == themePreviewImage)
+    else if (Id == themePreviewImage)
     {
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
@@ -274,13 +274,13 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         m_ui->downloadPushButton->setEnabled(true);
 
     }
-    if (Id == themeButtonIds)
+    else if (Id == themeButtonIds)
     {
         dbButtonIdsList = sList;
         this->getThemeButtonsByIds();
 
     }
-    if (Id == buttonData) // COPY BUTTONS AND MAKE FOLDERS
+    else if (Id == buttonData) // COPY BUTTONS AND MAKE FOLDERS
     {
         themeButtonIndex++;
         progressValue += 100 / (dbButtonIdsList.count()+2);
@@ -341,7 +341,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         // Get button imagedatas and make .png files
         this->getUnpressedImage();
     }
-    if (Id == unpressedToFile) // Name always unpressed.png
+    else if (Id == unpressedToFile) // Name always unpressed.png
     {
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
@@ -350,7 +350,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/unpressed.png","PNG");
         this->getPressedImage();
     }
-    if (Id == pressedToFile) // Name always pressed.png
+    else if (Id == pressedToFile) // Name always pressed.png
     {
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
@@ -359,7 +359,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         previewPix.save(buttonPath+"/pressed.png","PNG");
         this->getThemeButtonsByIds();
     }
-    if (Id == themeBgIds)
+    else if (Id == themeBgIds)
     {
         dbBackgroundIdsList = sList;
         if(dbBackgroundIdsList.count() > 0 && !dbBackgroundIdsList.contains("0"))
@@ -391,7 +391,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
              }
         }
     }
-    if (Id == bgData)
+    else if (Id == bgData)
     {
         themeBgIndex++;
         progressValue += 100 / (dbButtonIdsList.count()+2);
@@ -418,7 +418,7 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         // Get background imagedatas and make .png files
         this->getBgImage();
     }
-    if (Id == bgToFile)
+    else if (Id == bgToFile)
     {
         QPixmap previewPix(128,128);
         QByteArray pb = data.toByteArray();
@@ -427,27 +427,27 @@ void ThemeManager::processReturnValue(int Id,QVariant data)
         previewPix.save(bgPath+"/image.png","PNG");
         this->getThemeBackgroundsByIds();
     }
-    if (Id == uploadTheme)
+    else if (Id == uploadTheme)
     {
         bool ok;
         themeIdToUpload = data.toInt(&ok);
         this->uploadThemeButton();
     }
-    if (Id == addButtonToTheme)
+    else if (Id == addButtonToTheme)
     {
         progressItemCount += 100 / uploadItemsCount;
         emit progressState(progressItemCount);
         uploadButtonIndex++;
         this->uploadThemeButton();
     }
-    if (Id == addBgToTheme)
+    else if (Id == addBgToTheme)
     {
         progressItemCount += 100 / uploadItemsCount;
         emit progressState(progressItemCount);
         uploadBgIndex++;
         this->uploadThemeBg();
     }
-    if (Id == setThemeDownloadable)
+    else if (Id == setThemeDownloadable)
     {
         bool upload = data.toBool();
         if(upload)
@@ -751,12 +751,13 @@ void ThemeManager::getThemeVersionIds()
 }
 void ThemeManager::error(int i ,QString string)
 {
-    QMessageBox::warning(this,"Error",""+ string,
+    QMessageBox::warning(this,"Error: "+QString::number(i,10),string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void ThemeManager::fault(int i,int j,QString string)
 {
-    QMessageBox::warning(this,"Fault",""+ string,
+    Q_UNUSED(j);
+    QMessageBox::warning(this,"Fault: "+QString::number(i,10),string,
                      QMessageBox::NoButton,QMessageBox::NoButton);
 }
 void ThemeManager::loadThemes()
