@@ -26,6 +26,8 @@ public:
     explicit ThemeManager(QWidget *parent = 0);
     //! Destructor.
     virtual ~ThemeManager();
+    //! Setup remotestartup ui.
+    void setRemoteStartupProperties();
 
 protected:
     virtual void changeEvent(QEvent *e);
@@ -163,6 +165,9 @@ private:
 
     void deleteTheme(QString delThemeName);
 
+    //! Flag for remotestartup usage.
+    bool remoteStartup;
+
 
 
 private slots:
@@ -194,6 +199,7 @@ signals:
     void progressState(int state);
     //! Signal for progressbar.
     void themeUploaded();
+    void themeChoosed(const QString &themeName);
     //void startingDownload();
 };
 #endif // THEMEMANAGER_H
